@@ -307,13 +307,13 @@ gen.pseudo.seals <- function(prey.mat, diet.null.mat, cal.mat, fat.cont, noise,
 
         for(i in 1.:ns) {
             ## Split prey
-            prey.out <- split.prey(prey.mat)
+            prey.out <- split_prey(prey.mat)
             prey.sim <- prey.out[[1]]
             prey.mod <- prey.out[[2]]
 
             ## Split fat content for each species
             for(k in 1.:I) {
-                fat.split <- split.fatcont(fat.cont[prey.mat[, 1.] == unique(prey.mat[, 1.])[k]])
+                fat.split <- split_fatcont(fat.cont[prey.mat[, 1.] == unique(prey.mat[, 1.])[k]])
                 fat.sim[k] <- fat.split[1]
                 fat.mod[i, k] <- fat.split[2]
             }
@@ -337,13 +337,13 @@ gen.pseudo.seals <- function(prey.mat, diet.null.mat, cal.mat, fat.cont, noise,
 
         for(i in 1.:ns) {
             ## Split prey
-            prey.out <- split.prey(prey.mat)
+            prey.out <- split_prey(prey.mat)
             prey.sim <- prey.out[[1]]
             prey.mod <- prey.out[[2]]
 
             ## Split fat content for each species
             for(k in 1.:I) {
-                fat.split <- split.fatcont(fat.cont[prey.mat[  , 1.] == unique(prey.mat[,1.])[k]])
+                fat.split <- split_fatcont(fat.cont[prey.mat[  , 1.] == unique(prey.mat[,1.])[k]])
                 fat.sim[k] <- fat.split[1]
                 fat.mod[i, k] <- fat.split[2]
             }
@@ -372,7 +372,7 @@ gen.pseudo.seals <- function(prey.mat, diet.null.mat, cal.mat, fat.cont, noise,
 #' @param prey.mat matrix of individual prey fatty acid signatures
 #'     where the first column denotes the prey type
 #'
-split.prey <- function(prey.mat) {
+split_prey <- function(prey.mat) {
 
     numprey <- tapply(prey.mat[, 1.], prey.mat[, 1.], length)
 
@@ -408,7 +408,7 @@ split.prey <- function(prey.mat) {
     return(split.prey.list)
 }
 
-split.fatcont <- function(fat.cont.k) {
+split_fatcont <- function(fat.cont.k) {
 
     ## USED TO RANDOMLY SPLIT FAT CONTENT FOR SPECIES K IN TWO
     fat.cont.k <- fat.cont.k[!is.na(fat.cont.k)]
@@ -861,7 +861,7 @@ bias.all <- function(p.mat,
 
         for (n in 1.:R.bias) {
 
-            prey.split <- split.prey(prey.mat)
+            prey.split <- split_prey(prey.mat)
             prey.sim <- prey.split[[1]]
             prey.mod <- prey.split[[2]]
 
@@ -870,7 +870,7 @@ bias.all <- function(p.mat,
             prey.mod.ext[, -1.] <- prey.mod.ext[, -1.]/apply(prey.mod.ext[, -1.], 1., sum)
             for (k in 1.:I) {
 
-                fat.split <- split.fatcont(fat.cont[prey.mat[  , 1.] == unique(prey.mat[, 1.])[k]])
+                fat.split <- split_fatcont(fat.cont[prey.mat[  , 1.] == unique(prey.mat[, 1.])[k]])
                 fat.sim[k] <- fat.split[1]
                 fat.mod[k] <- fat.split[2]
             } # END k
